pub struct ConnectionLayer {
pub connection_id: ConnectionId,
pub murmur3_hash: u32,
}Expand description
Represents the header of a connection with an ID and a Murmur3 hash.
Fields
connection_id: ConnectionIdmurmur3_hash: u32Trait Implementations
Sourceimpl Debug for ConnectionLayer
impl Debug for ConnectionLayer
impl Eq for ConnectionLayer
Sourceimpl PartialEq for ConnectionLayer
impl PartialEq for ConnectionLayer
Sourcefn eq(&self, other: &ConnectionLayer) -> bool
fn eq(&self, other: &ConnectionLayer) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ConnectionLayer